==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Prebrano");
define("_BROWSERS","Brskalnik");
define("_OPERATINGSYS","Operacijski sistem");
define("_UNKNOWN","Nepoznano");
define("_OTHER","Drugi / Nepoznani");
define("_MISCSTATS","Razne statistike");
define("_REGUSERS","Registriranih uporabnikov:");
define("_ACTIVEAUTHORS","Aktivnih avtorjev:");
define("_STORIESPUBLISHED","Objavljenih lankov:");
define("_SACTIVETOPICS","Aktivnih tem:");
define("_COMMENTSPOSTED","Poslanih komentarjev:");
define("_SSPECIALSECT","Posebnih oddelkov:");
define("_ARTICLESSEC","lanakov v oddelkih:");
define("_LINKSINLINKS","Povezav:");
define("_LINKSCAT","Kategorij v povezavah:");
define("_NEWSWAITING","Novice na akanju:");
define("_NUKEVERSION","PHP-Nuke verzija:");
define("_SEARCHENGINES","Iskalniki");
define("_BOTS","Roboti/Pajki");
define("_STATS","Statistike dostopa");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Prebrano");
define("_BROWSERS","Brskalnik");
define("_OPERATINGSYS","Operacijski sistem");
define("_UNKNOWN","Nepoznano");
define("_OTHER","Drugi / Nepoznani");
define("_MISCSTATS","Razne statistike");
define("_REGUSERS","Registriranih uporabnikov:");
define("_ACTIVEAUTHORS","Aktivnih avtorjev:");
define("_STORIESPUBLISHED","Objavljenih lankov:");
define("_SACTIVETOPICS","Aktivnih tem:");
define("_COMMENTSPOSTED","Poslanih komentarjev:");
define("_SSPECIALSECT","Posebnih oddelkov:");
define("_ARTICLESSEC","lanakov v oddelkih:");
define("_LINKSINLINKS","Povezav:");
define("_LINKSCAT","Kategorij v povezavah:");
define("_NEWSWAITING","Novice na akanju:");
define("_NUKEVERSION","PHP-Nuke verzija:");
define("_SEARCHENGINES","Iskalniki");
define("_BOTS","Roboti/Pajki");
define("_STATS","Statistike dostopa");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
